@@ -1,6 +1,7 @@
 from dataclasses import field
 
 import jax
+import jax.tree_util as jtu
 import pytest
 from jax import numpy as jnp
 
@@ -116,15 +117,32 @@ def test_post_init():
     assert t.a == 2
 
 
-def test_overriding_setattr():
+def test_subclassing():
+    @pytc.treeclass
+    class L0:
+        a: int = 1
+        b: int = 3
+        c: int = 5
 
-    with pytest.raises(TypeError):
+        def inc(self, x):
+            return x
 
-        @pytc.treeclass
-        class Test:
-            a: int = 1
+        def sub(self, x):
+            return x - 10
 
-            def __setattr__(self, k, v):
-                object.__setattr__(self, k, v)
+    @pytc.treeclass
+    class L1(L0):
+        a: int = 2
+        b: int = 4
 
-        Test()
+        def __setattr__(self, name, value):
+            super().__setattr__(name, value)
+
+        def inc(self, x):
+            return x + 10
+
+    l1 = L1()
+
+    assert jtu.tree_leaves(l1) == [2, 4, 5]
+    assert l1.inc(10) == 20
+    assert l1.sub(10) == 0
